@@ -64,7 +64,9 @@ class GCPEntitiesRequestModel(RequestModel):
 class AmazonComprehendSentimentRequestModel(RequestModel):
     aws_access_key: str
     aws_secret_access_key: str
-    region_name: str
+    region_name: Literal['us-east-2', 'us-east-1', 'us-west-2', 'ap-south-1', 'ap-northeast-2', 'ap-southeast-1',
+                         'ap-southeast-2', 'ap-northeast-1', 'ca-central-1', 'eu-central-1', 'eu-west-1', 'eu-west-2',
+                         'us-gov-west-1']
     language_code: Literal['en', 'es', 'fr', 'de', 'it', 'pt', 'ar', 'hi', 'ja', 'ko', 'zh', 'zh-TW']
 
     def build(self) -> Request:
